@@ -8,26 +8,19 @@ import contextlib
 import os
 import sys
 
-from decentra_network.lib.cache import Cache
-
 sys.path.append(os.path.join(os.path.dirname(__file__), "..", ".."))
 
 from decentra_network.lib.config_system import get_config
 
 
 def CleanUp_tests():
-    for i in Cache.cache:
-        if (i.startswith("db/test_") and i.endswith("_conn")
-                and Cache.get(i) is not None):
-            Cache.get(i).close()
-    Cache.clear()
 
     os.chdir(get_config()["main_folder"])
     for the_file in os.listdir("db/"):
         if the_file.startswith("test_"):
             if os.path.isfile(f"db/{the_file}"):
-
-                os.remove(f"db/{the_file}")
+                with contextlib.suppress(PermissionError):
+                    os.remove(f"db/{the_file}")
 
     for the_file in os.listdir(
             "db/test_SaveBlockstoBlockchainDB_GetBlockstoBlockchainDB/"):
